#[non_exhaustive]pub struct ConnectionSnapshot {
pub stats: ConnectionStats,
pub version: Version,
}Expand description
Statistics and protocol sampled from the same live connection.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.stats: ConnectionStatsTransport statistics at the time of the snapshot.
version: VersionProtocol negotiated by the connection that supplied these statistics.