#[non_exhaustive]pub struct PeerIdentity {
pub dns_name: Option<String>,
}Expand description
The identity of a peer that presented a client certificate during the TLS
handshake, as validated against the configured ServerTlsConfig::root.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.dns_name: Option<String>The first DNS SAN on the leaf certificate, if any.
This is cryptographically bound to the cert and is suitable as a stable node name.