Helper library for native MoQ applications.
Establishes MoQ connections over:
- WebTransport (HTTP/3)
- Raw QUIC (with ALPN negotiation)
- WebSocket (fallback via web-transport-ws)
- Iroh P2P (requires
irohfeature)
See Client for connecting to relays and Server for accepting connections.
Re-exports
Modules
Structs
- Backoff
- Exponential backoff configuration for reconnection attempts.
- Client
- Client for establishing MoQ connections over QUIC, WebTransport, or WebSocket.
- Client
Config - Configuration for the MoQ client.
- Log
- Tracing log configuration.
- Reconnect
- Handle to a background reconnect loop.
- Request
- An incoming MoQ session that can be accepted or rejected.
- Server
- Server for accepting MoQ connections over QUIC.
- Server
Config - Configuration for the MoQ server.
- Server
Id - Server ID for QUIC-LB support.
Enums
- Connect
Error - Error returned when connection setup fails for a terminal auth reason.
- Error
- Errors produced while configuring or establishing native MoQ connections.
- Quic
Backend - The QUIC backend to use for connections.
- Status
- A connection lifecycle transition reported by
Reconnect::status.
Type Aliases
- Result
- Convenience alias for results produced by this crate.