#[non_exhaustive]pub struct ClientConfig {
pub bind: SocketAddr,
pub backend: Option<QuicBackend>,
pub max_streams: Option<u64>,
pub version: Vec<Version>,
pub tls: ClientTls,
pub websocket: ClientWebSocket,
}Expand description
Configuration for the MoQ client.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bind: SocketAddrListen for UDP packets on the given address.
backend: Option<QuicBackend>The QUIC backend to use. Auto-detected from compiled features if not specified.
max_streams: Option<u64>Maximum number of concurrent QUIC streams per connection (both bidi and uni).
version: Vec<Version>Restrict the client to specific MoQ protocol version(s).
By default, the client offers all supported versions and lets the server choose.
Use this to force a specific version, e.g. --client-version moq-lite-02.
Can be specified multiple times to offer a subset of versions.
Valid values: moq-lite-01, moq-lite-02, moq-lite-03, moq-transport-14, moq-transport-15, moq-transport-16
tls: ClientTlswebsocket: ClientWebSocketImplementations