pub struct Listener { /* private fields */ }Expand description
Listens for incoming WebSocket connections on a TCP port.
Use with crate::Server::with_websocket to accept WebSocket connections
alongside QUIC connections on a separate port.
Implementations
Sourceimpl Listener
impl Listener
Sourcepub async fn bind(addr: SocketAddr) -> Result<Self, Error>
pub async fn bind(addr: SocketAddr) -> Result<Self, Error>
Bind a listener to the given address, accepting every moq ALPN we know about.
Sourcepub async fn bind_with_alpns(
addr: SocketAddr,
alpns: &[&str],
) -> Result<Self, Error>
pub async fn bind_with_alpns( addr: SocketAddr, alpns: &[&str], ) -> Result<Self, Error>
Bind a listener that only accepts the given moq ALPNs, in preference order.
Sourcepub fn local_addr(&self) -> Result<SocketAddr, Error>
pub fn local_addr(&self) -> Result<SocketAddr, Error>
The local address the listener is bound to.